@@ -1,7 +1,7 @@
-__version__ = "0.2.0"
+__version__ = "0.2.1"
 
 __title__ = "pygohome"
-__description__ = "Snowball effect in language learning"
+__description__ = "A 100% personal route optimizer in a known environment based on experience."
 __url__ = "https://github.com/eumiro/pygohome/"
 __uri__ = __url__
 __doc__ = __description__ + " <" + __uri__ + ">"
